@@ -26,7 +26,11 @@
 #include <QString>
 #include <QPixmap>
 #include <QStandardItem>
+#include <QStandardPaths>
+#include <QFileDialog>
+#include <QPointer>
 
+#include <KNS3/DownloadDialog>
 #include <KTar>
 #include <KZip>
 
@@ -48,6 +52,8 @@ ChoicePage::ChoicePage(QWidget *parent)
     connect(ui_choice.kcfg_appName, SIGNAL(textChanged(const QString &)), this, SIGNAL(completeChanged()));
     connect(this, SIGNAL(completeChanged()), this, SLOT(saveConfig()));
     connect(ui_choice.appTree->selectionModel(), SIGNAL(currentChanged(QModelIndex, QModelIndex)), this, SLOT(itemSelected(QModelIndex)));
+    connect(ui_choice.installButton, &QPushButton::clicked, this, &ChoicePage::loadFromFile);
+    connect(ui_choice.getNewButton, &QPushButton::clicked, this, &ChoicePage::getMoreTemplates);
     QRegExp rx("[a-zA-Z0-9_]*");
     QValidator *validator = new QRegExpValidator(rx, this);
     ui_choice.kcfg_appName->setValidator(validator);
@@ -143,6 +149,11 @@ void ChoicePage::itemSelected(const QModelIndex &index)
     if (picture.isNull()) {
         ui_choice.pictureLabel->setText(i18n("No sample picture available."));
     } else {
+        const QSize labelSize = ui_choice.pictureLabel->minimumSize();
+        if ((labelSize.height() < picture.height() || labelSize.width() < picture.width()) ||
+            (labelSize.height() > picture.height()*2 || labelSize.width() > picture.width()*2)) {
+            picture = picture.scaled(labelSize, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+        }
         ui_choice.pictureLabel->setPixmap(picture);
     }
 
@@ -163,3 +174,57 @@ void ChoicePage::itemSelected(const QModelIndex &index)
     emit templateNameChanged(m_baseName);
     emit completeChanged();
 }
+
+void ChoicePage::loadFromFile()
+{
+    QPointer<QFileDialog> fileDialog = new QFileDialog(this);
+
+    fileDialog->setMimeTypeFilters(QStringList()
+        << QStringLiteral("application/x-bzip-compressed-tar")
+        << QStringLiteral("application/zip"));
+    fileDialog->setFileMode(QFileDialog::ExistingFiles);
+
+    if (!fileDialog->exec()) {
+        delete fileDialog;
+        return;
+    }
+
+    const QStringList selectedFiles = fileDialog->selectedFiles();
+    delete fileDialog;
+
+    const QString saveLocation = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/kdevappwizard/templates/");
+
+    QDir dir(saveLocation);
+    if (!dir.exists()) {
+        dir.mkpath(QStringLiteral("."));
+    }
+
+    foreach (const QString& fileName, selectedFiles) {
+        qCDebug(KAPPTEMPLATE) << "Copying" << fileName << "to" << saveLocation;
+        QFileInfo info(fileName);
+        QFile::copy(fileName, saveLocation + info.fileName());
+    }
+
+    templatesModel->refresh();
+    ui_choice.appTree->expandAll();
+    ui_choice.appTree->setFocus(Qt::OtherFocusReason);
+}
+
+void ChoicePage::getMoreTemplates()
+{
+    QPointer<KNS3::DownloadDialog> dialog = new KNS3::DownloadDialog(QStringLiteral("kapptemplate.knsrc"), this);
+
+    if (!dialog->exec()) {
+        delete dialog;
+        return;
+    }
+
+    const bool hasChangedEntries = !dialog->changedEntries().isEmpty();
+    delete dialog;
+
+    if (hasChangedEntries) {
+        templatesModel->refresh();
+        ui_choice.appTree->expandAll();
+        ui_choice.appTree->setFocus(Qt::OtherFocusReason);
+    }
+}
